@@ -8,8 +8,7 @@ class GraphManager:
     def CreateTrainAndSaveGCN(self,documents,saved_folder, tagsPath):
         tags = self._getTagsList(tagsPath)
         traindata, testdata = get_data(documents=documents, tags=tags)
-        CreateTrainAndSaveGCN(traindata, testdata,saved_folder, len(tags))
-        print("===== Modèle entrainé et sauvegardé =====")
+        return CreateTrainAndSaveGCN(traindata, testdata,saved_folder, len(tags))
 
     def _getTagsList(self, tagsPath):
         tags = []
