@@ -10,10 +10,7 @@ from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects,ConvertPre
 
 def make_info(document):
     connect = Grapher(document)
-    G, _, _ = connect.graph_formation()
-    df = connect.relative_distance(document.width, document.height)
-    individual_data = from_networkx(G)
-    return G, df, individual_data
+    return connect.df
 
 def predictionsUnique(saved_model_folder,json,labels_tab):
     predictions_data = getDataForUniquePrediction(json,labels_tab)
@@ -32,7 +29,7 @@ def predictionsUnique(saved_model_folder,json,labels_tab):
     OBTENIR LE DOC EN DOC
     """
     document = ConvertJsonToDocumentsObjects(json)[0]
-    _, df, _ = make_info(document)
+    df = make_info(document)
 
     assert len(y_pred) == df.shape[0]
 
